fc_tools.utils.cleaning()
N=80;
[bvp,info]=fc_vfemp1.examples.setBVPElectrostatic2D01(N,2);
fc_vfemp1.examples.print_info(info)

fprintf('*** Solving %s\n',info.name)
[phi,SolveInfo]=bvp.solve('time',true);
fprintf('    -> ndof (number of degrees of freedom) = %d\n',length(phi));
fc_vfemp1.examples.print_info(SolveInfo)

fprintf('*** Computing the electric field E\n')
Th=bvp.Th;
tstart=tic();
Lop=fc_vfemp1.Loperator(2,2,[],[],{-1,0},[]);
Ex=Lop.apply(Th,phi); 
Lop=fc_vfemp1.Loperator(2,2,[],[],{0,-1},[]);
Ey=Lop.apply(Th,phi); 
E=[Ex,Ey];
ENorm=sqrt(Ex.^2+Ey.^2);
tcpu=toc(tstart);
fprintf('    -> Done it in %.3f(s)\n',tcpu)

if fc_tools.utils.is_fcPackage('siplt')
  fprintf('*** Graphics with fc_siplt package\n');
  fc_tools.graphics.monitors.onGrid(3,3,'figures',1:7,'covers',0.9);
  interpreter=@(x) fc_tools.graphics.interpreter(x);
  if fc_tools.comp.isOctave(),opt_interp={'interpreter','tex'};else,opt_interp={'interpreter','latex'};end
  
  tstart=tic();
  figure(1)
  Th.plotmesh('inlegend',true)
  legend('show')
  axis equal;axis off

  figure(2)
  Th.plotmesh('color',[0.8,0.8,0.8])
  Th.plotmesh('d',1,'LineWidth',1.5,'inlegend',true)
  legend('show')
  axis image

  figure(3)
  Th.plotmesh('d',1,'color',[0,0,0])
  hold on
  Th.plot(phi,'EdgeColor','None')
  axis image;axis off;
  colorbar()
  Th.plotiso(phi,'niso',20,'color','w','LineWidth',1) 
  Th.plotmesh('d',1,'color','w','LineWidth',1.5)
  shading interp
  title(interpreter('potentiel $\varphi$'),opt_interp{:})

  figure(4)
  Th.plotmesh('color',[0.85,0.85,0.85])
  hold on
  Th.plotmesh('d',1,'color',[0,0,0])
  [~,~,cax]=Th.plotiso(phi,'niso',25,'isocolorbar',true,'format','%.3f');
  axis image;axis off;
  title(interpreter('potentiel $\varphi$'),opt_interp{:})

  idxlab=Th.find(2,10);
  figure(5)
  Th.plotmesh('d',1,'color','k')
  hold on
  [~,~,cax]=Th.plotiso(phi,'niso',25,'isocolorbar',true,'format','%.3f');
  Th.plotquiver(E,'d',2,'labels',[10],'colordata',phi)
  axis image;axis off;
  title(interpreter('potentiel $\varphi$ and electric field $E$'),opt_interp{:})

  figure(6)
  Th.plot(ENorm,'EdgeColor','None')
  hold on
  axis image;axis off;
  colorbar()
  Th.plotiso(ENorm,'niso',20,'color','w','LineWidth',1) 
  Th.plotmesh('d',1,'color','k','LineWidth',1.5)
  shading interp
  title(interpreter('Norm of the electric field $E$'),opt_interp{:})

  figure(7)
  Th.plotmesh('d',1,'color',[0,0,0])
  hold on
  [~,~,cax]=Th.plotiso(ENorm,'niso',25,'isocolorbar',true,'format','%.3f');
  axis image;axis off;
  title(interpreter('Norm of the electric field $E$'),opt_interp{:})
  
  drawnow
  tcpu=toc(tstart);
  fprintf('    -> Done it in %.3f(s)\n',tcpu)
end
